pub struct Bar<'a, const SIZE: usize = 0> { /* private fields */ }Expand description
A PCI BAR to perform I/O-Operations on.
I/O backend assumes that the device is little-endian and will automatically convert from little-endian to CPU endianness.
Invariants
Bar always holds an IoRaw instance that holds a valid pointer to the start of the I/O
memory mapped PCI BAR and its size.
Implementations
Sourceimpl<'a, const SIZE: usize> Bar<'a, SIZE>
impl<'a, const SIZE: usize> Bar<'a, SIZE>
Sourcepub fn into_devres(self) -> Result<DevresBar<SIZE>>
pub fn into_devres(self) -> Result<DevresBar<SIZE>>
Consume the Bar and register it as a device-managed resource.
The returned DevresBar can outlive the original borrow and be stored in driver data.
Access to the BAR is revoked automatically when the device is unbound.